femeta: Improved Inference for Fixed-effects Meta-analysis with...

Description Usage Arguments Examples

View source: R/femeta.R

Description

Obtaining the confidence interval of logarithm of Cochran-Mantel-Haenszel estimator, Woolf's estimator of MLE of an assumed-common log odds ratio without assuming homogeneity

Usage

1
2
3
4
femeta(x, ai, bi, ci, di, n1i, n2i, data, slab, subset,
  correction_factor = 0.01, drop00 = FALSE, estimator = "log-CMH",
  vtype = "Het", alternative = "two.sided", conf.level = 0.95,
  null.value = 0)

Arguments

x

a 2x2xK array that gives the counts of cases and non-cases in treatment and control arms in each study

ai

vector to specify the 2x2 table frequencies (upper left cell); number of cases in the treatment arms.

bi

vector to specify the 2x2 table frequencies (upper right cell); number of cases in the control arms.

ci

vector to specify the 2x2 table frequencies (lower left cell); number of non-cases in the treatment arms.

di

vector to specify the 2x2 table frequencies (lower right cell); number of non-cases in the control arms.

n1i

vector to specify the group sizes or column totals (first group/column).

n2i

vector to specify the groups sizes or column totals (second group/column).

data

optional data frame containing the variables given to the arguments above.

slab

optional vector with labels for the studies.

subset

optional vector indicating the subset of studies that should be used. This can be a logical vector or a numeric vector indicating the indices of the studies to include.

correction_factor

A scalar used for zero-cell correction. Intuitively it is the total number of subjects added to each group of a study. A small correction factor induces less bias. The default is 0.01. See 'Details'.

drop00

logical indicating whether studies with no cases/events (or only cases) in both groups should be dropped when calculating the observed outcomes of the individual studies. See 'Details'.

estimator

a character string indicating which estimator is used to summarize to overall association (either "log-CMH", "Woolf" or "CEMLE"). See 'Details'.

vtype

a character string indicating whether to assume homogeneity when calculating the variance (either "Het" or "Hom).

alternative

a character string indicating the alternative hypothesis and must be one of "two.sided", "greater" or "less". You can specify just the initial letter.

conf.level

a scalar indicating the confidence level for the returned confidence interval.of the

null.value

scalar indicating the value of the parameter of interest (some summary of the true effect sizes)

Examples

1
2
3
4
5
6
7
8
data(sclerotherapy)

### a meta analysis of 19 studies investigating the effect of sclerotherapy
### on first bleeding.
### we use Woolf's estimator to summarize the overall association

femeta(ai = tcases, bi = ccases, n1i = tcounts, n2i = ccounts,
data = sclerotherapy, estimator = "Woolf")

KenLi93/FEMetaBin documentation built on Oct. 30, 2019, 8:15 p.m.