sclerotherapy: Effect of sclerotherapy in preventing first bleeding in...

Description Usage Format Source

Description

A meta-analysis of 19 study data, each contains the number of cases of first bleeding in the control group and the treatment group that receives sclerotherapy

Usage

1

Format

A data frame with 19 rows and 5 variables:

trial

name of the trial or author names of the publication

ccounts

number of patients in the control arm

tcounts

number of patients in the treatment arm

ccases

number of cases of first bleeding in the control arm

tcases

number of cases of first bleeding in the treatment arm

http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.824.9882&rep=rep1&type=pdf


KenLi93/FEMetaBin documentation built on Oct. 30, 2019, 8:15 p.m.