Description Usage Format Source
A meta-analysis of 19 study data, each contains the number of cases of first bleeding in the control group and the treatment group that receives sclerotherapy
1 |
A data frame with 19 rows and 5 variables:
name of the trial or author names of the publication
number of patients in the control arm
number of patients in the treatment arm
number of cases of first bleeding in the control arm
number of cases of first bleeding in the treatment arm
http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.824.9882&rep=rep1&type=pdf
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.